summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kopeteprotocol.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/kopeteprotocol.h')
-rw-r--r--kopete/libkopete/kopeteprotocol.h17
1 files changed, 9 insertions, 8 deletions
diff --git a/kopete/libkopete/kopeteprotocol.h b/kopete/libkopete/kopeteprotocol.h
index 546247cf..64cab27c 100644
--- a/kopete/libkopete/kopeteprotocol.h
+++ b/kopete/libkopete/kopeteprotocol.h
@@ -58,6 +58,7 @@ class Account;
class KOPETE_EXPORT Protocol : public Plugin
{
Q_OBJECT
+ TQ_OBJECT
public:
@@ -85,7 +86,7 @@ public:
*
* @return A new AddContactPage to be shown in the Add Contact Wizard
*/
- virtual AddContactPage *createAddContactWidget( TQWidget *parent, Account *account ) = 0;
+ virtual AddContactPage *createAddContactWidget( TQWidget *tqparent, Account *account ) = 0;
/**
* @brief Create a new KopeteEditAccountWidget
@@ -93,13 +94,13 @@ public:
* @return A new KopeteEditAccountWidget to be shown in the account part of the configurations.
*
* @param account is the KopeteAccount to edit. If it's 0L, then we create a new account
* @param parent The parent of the 'to be returned' widget
*/
- virtual KopeteEditAccountWidget * createEditAccountWidget( Account *account, TQWidget *parent ) = 0;
+ virtual KopeteEditAccountWidget * createEditAccountWidget( Account *account, TQWidget *tqparent ) = 0;
/**
- * @brief a bitmask of the capabilities of this protocol
+ * @brief a bittqmask of the capabilities of this protocol
* @sa @ref setCapabilities
*/
unsigned int capabilities() const ;
@@ -131,7 +132,7 @@ public:
RichIFormatting = 0x400,
RichBFormatting = 0x800,
- Alignment = 0x1000, ///< Setting the alignment of text portions
+ Alignment = 0x1000, ///< Setting the tqalignment of text portions
/// Setting the formatting of the whole edit widget / message
BaseFormatting = BaseIFormatting | BaseUFormatting | BaseBFormatting,
@@ -152,7 +153,7 @@ public:
/**
* @brief Returns the status used for contacts when accounts of this protocol are offline
*/
- Kopete::OnlineStatus accountOfflineStatus() const;
+ Kopete::OnlineStatus accountOfflinetqStatus() const;
protected:
@@ -160,10 +161,10 @@ protected:
* @brief Constructor for Protocol
*
* @param instance The protocol's instance, every plugin needs to have a KInstance of its own
* @param parent The protocol's parent object
* @param name The protocol's name
*/
- Protocol( KInstance *instance, TQObject *parent, const char *name );
+ Protocol( KInstance *instance, TQObject *tqparent, const char *name );
/**
* @brief Sets the capabilities of this protcol.
@@ -93,13 +94,13 @@ public:
*
* @param account is the KopeteAccount to edit. If it's 0L, then we create a new account
- * @param parent The parent of the 'to be returned' widget
+ * @param tqparent The tqparent of the 'to be returned' widget
*/
@@ -160,10 +161,10 @@ protected:
*
* @param instance The protocol's instance, every plugin needs to have a KInstance of its own
- * @param parent The protocol's parent object
+ * @param tqparent The protocol's tqparent object
* @param name The protocol's name
*/